@@ -89,8 +89,10 @@ int main(int argc, char *argv[])
 		family = NFPROTO_IPV4;
 	else if (strcmp(argv[1], "ip6") == 0)
 		family = NFPROTO_IPV6;
+	else if (strcmp(argv[1], "inet") == 0)
+		family = NFPROTO_INET;
 	else {
-		fprintf(stderr, "Unknown family: ip, ip6\n");
+		fprintf(stderr, "Unknown family: ip, ip6, inet\n");
 		exit(EXIT_FAILURE);
 	}
 
